@@ -27,6 +27,12 @@ from subprocess import *
 from pge_buffer import SyntaxLoader,CodeBuffer
 import pge_preferences 
 
+def is_space_or_tab(char,userdata):
+  if (char==' ') or (char=='\t'):
+    return False
+  else:
+    return True
+
 ###############################################################################
 # @brief Code editor widget
 ###############################################################################
@@ -245,9 +251,18 @@ class Editor (hildon.TextView):
 
     if (buffer.get_selection_bounds()!=()):
       start,end=buffer.get_selection_bounds()
-      for line in range(start.get_line(),end.get_line()+1):
-        text = buffer.get_text(buffer.get_iter_at_line(line),buffer.get_iter_at_line(line+1))
-        buffer.insert(buffer.get_iter_at_line(line),text)
+      start.set_line_offset(0)
+      end.forward_to_line_end()
+      insert = end.copy()
+      text = ''
+      if end.is_end():
+        text = '\n'
+        insert.forward_to_end()
+      else:
+        insert.forward_line()
+      text = text+buffer.get_text(start,end)
+      buffer.insert(insert,text)
+    
     else:
       insert = buffer.get_iter_at_mark(buffer.get_insert())
       start = buffer.get_iter_at_line(insert.get_line())
@@ -256,8 +271,11 @@ class Editor (hildon.TextView):
       if start.get_line() == end.get_line():
         _,end = buffer.get_bounds()
         text = '\n'
+        insert.forward_to_end()
+      else:
+        insert.forward_line()
       text = text+buffer.get_text(start,end)
-      buffer.insert(buffer.get_iter_at_line(insert.get_line()),text)
+      buffer.insert(insert,text)
 
   #############################################################################
   # @brief Insert tabulation
@@ -312,7 +330,22 @@ class Editor (hildon.TextView):
       return '--'
     else:
       return '//'
-
+      
+  #############################################################################
+  # @brief Remove space and tabs at end of line for all text in buffer
+  #############################################################################
+  def clean_line_end(self):
+    buffer = self.get_buffer()
+    start,end=buffer.get_bounds()
+    for line in range(start.get_line(),end.get_line()+1):
+      end_line_iter = buffer.get_iter_at_line(line)
+      end_line_iter.forward_to_line_end()
+      start_delete_iter = end_line_iter.copy()
+      start_delete_iter.backward_find_char(is_space_or_tab,None,buffer.get_iter_at_line(line))
+      if (start_delete_iter.get_char() != ' ') and (start_delete_iter.get_char() != '\t'):
+        start_delete_iter.forward_char()
+      buffer.delete(start_delete_iter,end_line_iter)
+      
   #############################################################################
   # @brief Comment / Uncomment
   #############################################################################
