@@ -166,6 +166,10 @@ Roadmap :
 ◦ Fix about menu : #9326
 ◦ Fix line number : #8814
 
+•Version 3.0.13 :
+◦ Link to bugtracker
+◦ Implement autoclean space at end of line feature
+
 •Version 3.3.0 :
 ◦ Plugins
 ◦ Snippet
