@@ -245,6 +245,8 @@ class Window(hildon.Window):
 
   def save_file(self,filepath):
     try:
+      if self.prefs.prefs_dict['auto_clean_line_end']==True:
+        self.code_editor.clean_line_end()
       f = open(filepath,'w')
       buf = self.code_editor.get_buffer()
       start,end = buf.get_bounds()
